pub fn approval_config_from_env() -> ApprovalConfigExpand description
Resolve the approval set + denied index from the environment. Empty when the vars are absent, which is the first-run (nothing approved yet) case.
pub fn approval_config_from_env() -> ApprovalConfigResolve the approval set + denied index from the environment. Empty when the vars are absent, which is the first-run (nothing approved yet) case.