Modules
Constants
- BLOCK_
GLOBALS_ ENV - Comma-separated list of additional globals to nil out at VM
creation time (defense-in-depth knob for hardened deployments).
Names support dotted paths into stdlib tables — e.g.
ASSAY_BLOCK_GLOBALS=dofile,os.execute,debug.getinfo. - MODULES_
PATH_ ENV - Environment variable to override the global module search path.